@@ -291,6 +291,9 @@ def main():
             add[plugin.id()] = [plugin_want[p] for p in plugin_want.keys() - installed]
             remove[plugin.id()] = installed - plugin_want.keys()
 
+        for k, v in list(remove.items()):
+            remove[k] = list(v)
+
         print(
             "\nPlan: Adding--\n{}".format(luxem.dumps(add, pretty=True).decode("utf-8"))
         )
@@ -302,11 +305,11 @@ def main():
         if not args.dry_run:
             for plugin in plugins:
                 print(f"Installing packages for {plugin.id()}...")
-                plugin_add = list(add.get(plugin.id(), set()))
+                plugin_add = add.get(plugin.id(), [])
                 if plugin_add:
                     plugin.install(plugin_add)
                 print(f"Removing packages for {plugin.id()}...")
-                plugin_remove = list(remove.get(plugin.id(), set()))
+                plugin_remove = remove.get(plugin.id(), [])
                 if plugin_remove:
                     plugin.uninstall(plugin_remove)
 
